diff --git a/endpoints/common.py b/endpoints/common.py
index cf22f5a35..b79dca4ff 100644
--- a/endpoints/common.py
+++ b/endpoints/common.py
@@ -211,7 +211,7 @@ def render_page_template(name, route_data=None, **kwargs):
google_tagmanager_key=app.config.get('GOOGLE_TAGMANAGER_KEY', ''),
sentry_public_dsn=app.config.get('SENTRY_PUBLIC_DSN', ''),
is_debug=str(app.config.get('DEBUGGING', False)).lower(),
- show_chat=features.OLARK_CHAT,
+ show_chat=features.SUPPORT_CHAT,
aci_conversion=features.ACI_CONVERSION,
has_billing=features.BILLING,
contact_href=contact_href,
diff --git a/templates/base.html b/templates/base.html
index d9861adbe..b21d10141 100644
--- a/templates/base.html
+++ b/templates/base.html
@@ -240,26 +240,13 @@ mixpanel.init("{{ mixpanel_key }}", { track_pageview : false, debug: {{ is_debug
{% if show_chat %}
-
-
-
+
{% endif %}
{% if google_tagmanager_key %}
diff --git a/config.py b/config.py
index f24300dd6..7bb083710 100644
--- a/config.py
+++ b/config.py
@@ -157,8 +157,8 @@ class DefaultConfig(object):
# Feature Flag: Whther Dex login is supported.
FEATURE_DEX_LOGIN = False
- # Feature flag, whether to enable olark chat
- FEATURE_OLARK_CHAT = False
+ # Feature flag, whether to enable support chat
+ FEATURE_SUPPORT_CHAT = False
# Feature Flag: Whether to support GitHub build triggers.
FEATURE_GITHUB_BUILD = False